<?php
    
namespace  HCM\FPA\ObrigacaoLegal\Rais;

use HCM\Geral\Util\MsgCalculo;

use HCM\Util\DateUtil;
use HCM\Util\Repositories;
use HCM\Util\FPA;
use HCM\FPA\ObrigacaoLegal\Rais\Tipo00;
use HCM\FPA\ObrigacaoLegal\Rais\QuerysRais;


class GeraRais {
    const REFERENCIA_PROJETA = 'RAIS_PROJETA_RESCISAO'; //Projeta a rescisão na RAIS. '1' = projeta, 0 ou a inexistência deste = não projeta
    
    protected $rais;
    protected $magnetico;
    protected $formRais;

    protected $ano;
    protected $nrorg;
    protected $dtmescompetenc;

    protected $nrestruturasm;
    protected $nrvinculosm;
    protected $vinculos;

    protected $estrutResponsavel;
    protected $pessoaResponsavel;
    protected $retificacao;

    function __construct($hcmParameters,$entityManager) {
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->nrorg = $hcmParameters->getNrorgTrabalho();
        $this->dtmescompetenc = $hcmParameters->getDtCompetencia();
        $this->ano = DateUtil::getDataDeString($this->hcmParameters->getDtCompetencia())->format('Y');
        $this->queryRais = new QuerysRais($this->entityManager,$this->hcmParameters);
    }

    public function setFormRais($nrformrais) {
        $this->formRais = $this->entityManager->getRepository(Repositories::FPA_FORMRAIS)->getFpaFormRais($this->nrorg,$nrformrais);
        if(!$this->formRais){
            throw new \Exception("Formulario não encontrado");
        }

        $this->retificacao = $this->formRais->getIdretifrais();
        $this->estrutResponsavel = $this->formRais->getNrestrutrespons();
        $this->pessoaResponsavel = $this->formRais->getNrpessoarespons();

        $this->aplicaFiltro($this->formRais->getDsordem(), $this->formRais->getNomeinicial(), $this->formRais->getNomefinal());
    }

    private function aplicaFiltro($ordem, $inicio, $fim) {
        $primeiroDiaAno = DateUtil::getPrimeiroDiaDoAno($this->hcmParameters->getDtCompetencia(),DateUtil::FORMATO_BRASILEIRO,true);
        $dtUltDiaMes = DateUtil::getUltimoDiaDoMes($this->hcmParameters->getDtCompetencia(),DateUtil::FORMATO_BRASILEIRO,true);
        
        $params = array(
            "inicio" => $inicio,
        );
        
        if($fim)
            $params['fim'] = $fim;
        
        $condProcesso = 'vm.nrorg = :p_nrorg
                        AND (vm.dtrescisaovinc is null OR vm.dtrescisaovinc >= :p_primeirodiaano)
                        AND vm.dtadmissaovinc <=  :p_dtultdiames
                        AND vm.nrtipovinculom in (1,3)';
        switch ($ordem) {
            case 'ALFABETICA':
                $condIntervalo = 'vm.nmvinculom BETWEEN :inicio AND :fim';
                break;
            case 'ESTRUTURA':
                    $condIntervalo  = ' vh.nrestrutlegal = :inicio';
                    
                    if($fim)
                        $condIntervalo .= " AND vh.nrestrutgeren = :fim";
                break;
            case 'MATRICULA':
                $condIntervalo = 'vm.cdmatricula BETWEEN :inicio AND :fim';
                break;
            case 'DATA_ADMISSAO':
                $condIntervalo = 'vm.dtadmissaovinc BETWEEN :inicio AND :fim';
                break;
            case 'LISTA_VINCULO':
                unset($params['inicio']);
                $inicio = is_array($inicio) ? implode(',',$inicio) : $inicio;
                $condIntervalo = "vm.nrvinculom IN ($inicio)";
                break;
            case 'LISTA_ESTRUTURA':
                unset($params['inicio']);
                unset($params['fim']);
                
                $inicio = is_array($inicio) ? implode(',',$inicio) : $inicio;
                $condIntervalo = "vh.nrestrutlegal IN ($inicio)";
                if($fim){
                    $fim = is_array($fim) ? implode(',',$fim) : $fim;
                    $condIntervalo .= "AND vh.nrestrutgeren IN ($fim)";
                }
                break; 
        }
        
        if ($ordem == 'ESTRUTURA') {
            $this->vinculos = $this->entityManager->getRepository(Repositories::GPE_VINCULOM)->retornaVinculosPorEstruturas($this->nrorg, $this->dtmescompetenc, $condProcesso, $condIntervalo, 'order by vm.nmvinculom', null, true, null, null, null, $params, true);
        } else {
            $this->vinculos = $this->entityManager->getRepository(Repositories::GPE_VINCULOM)->retornaVinculos($this->nrorg, $this->dtmescompetenc, $condProcesso, $condIntervalo, 'order by vm.nmvinculom', null, true, null, null, null, $params, true);
        }
        
        /* Busca vínculos com rescisão em dezembro do ano anterior que tenha aviso prévio indenizado */
        $dtIniDezAnoAnt = clone($primeiroDiaAno);
        $dtIniDezAnoAnt = DateUtil::subtraiIntervalo($dtIniDezAnoAnt, 1, DateUtil::MES);
        $dtIniDezAnoAnt = DateUtil::adicionaIntervalo($dtIniDezAnoAnt, 1, DateUtil::DIA);

        $dtFimDezAnoAnt = clone($primeiroDiaAno);
        $dtFimDezAnoAnt = DateUtil::subtraiIntervalo($dtFimDezAnoAnt, 1);

        $condProcesso = 'vm.nrorg = '.$this->nrorg.'
                        AND vm.dtrescisaovinc BETWEEN :p_dtinidezanoant AND :p_dtfimdezanoant
                        AND vm.dtrescisaovinc = vm.dtavisoprevio
                        AND vm.nrtpdemissao = 2
                        AND vm.nrtipovinculom IN (1,3)';
        $params[':p_dtinidezanoant'] = $dtIniDezAnoAnt ;
        $params[':p_dtfimdezanoant'] = $dtFimDezAnoAnt ;
        
        if ($ordem == 'ESTRUTURA') {
            $vincRescAnoAnt = $this->entityManager->getRepository(Repositories::GPE_VINCULOM)->retornaVinculosPorEstruturas($this->nrorg, $dtIniDezAnoAnt, $condProcesso, $condIntervalo, 'order by vm.nmvinculom', null, true, null, null, null, $params, true);
        } else {
            $vincRescAnoAnt = $this->entityManager->getRepository(Repositories::GPE_VINCULOM)->retornaVinculos($this->nrorg, $dtIniDezAnoAnt, $condProcesso, $condIntervalo,'order by vm.nmvinculom',null,true,null,null,null,$params);
        }
        
        $this->vinculos = array_merge($this->vinculos, $vincRescAnoAnt);
        $nrestruturas = array();
        foreach ($this->vinculos as $vinculom) {
            array_push($nrestruturas,$vinculom->historico->getNrestrutlegal());
        }

        $this->nrestruturasm = array_unique($nrestruturas);

        unset($primeiroDiaAno);
        unset($dtUltDiaMes);
        unset($dtIniDezAnoAnt);
        unset($dtFimDezAnoAnt);
    }

    private function buscaResponsavel() {
        $estruturah = $this->entityManager->getRepository(Repositories::ESTRUTURAH)->retornaEstruturaHistorico($this->nrorg,$this->estrutResponsavel,$this->dtmescompetenc);
        if(!$estruturah){
            throw new Exception("Histórico da estrutura responsável pela RAIS não foi encontrado");
        }
        $this->estrutResponsavel = $estruturah;
        
        $pessoah = $this->entityManager->getRepository(Repositories::GPE_PESSOA)->retornaPessoaAtual($this->nrorg, $this->pessoaResponsavel, $this->dtmescompetenc);

        if(!$pessoah){
            throw new \Exception("Histórico da pessoa responsável pela RAIS não foi encontrado");
        }

        $this->pessoaResponsavel = $pessoah;
    }

    public function gerar($grpInciden, $centralPgto = null, $sindicato = null) {
        try {
            $idProjetaRescisao = (int)$this->entityManager->getRepository(Repositories::FPA_VALORREFERENCIAM)->buscavalor($this->nrorg, 0, $this->dtmescompetenc, self::REFERENCIA_PROJETA);
            
            $this->buscaResponsavel();
            $this->rais = new Tipo00($this->hcmParameters,$this->entityManager,$this->estrutResponsavel, $this->pessoaResponsavel, $this->nrorg, $this->ano, $this->formRais->getNrformrais(), $this->retificacao, $idProjetaRescisao);
            $this->rais->setTipo01($this->nrestruturasm, $centralPgto, $sindicato);
            
        } catch (\Exception $e) {
            throw $e;
        }
        $this->nrcalculo = $this->rais->setTipo02($grpInciden, $this->vinculos);
        
        $this->rais->setTipo09();
        
        $message = $this->entityManager->getRepository(Repositories::FPA_MSGCALCULO)->findBy(array('nrcalculofolha' => $this->nrcalculo, 'nrorg' => $this->hcmParameters->getNrorgTrabalho(), 'dsorigmsg' => 'RAIS'));
        return $message;
    }

    public function getTipo00()
    {
        return $this->rais;
    }

    public function preparaDados()
    {
        $info = $this->rais->getMagnetico($this->formRais->getIdgerameiomag());
        $this->magnetico = '';
        for($c = 0; $c<count($info);$c++){
            $this->magnetico .= str_pad($c+1, 6, '0', STR_PAD_LEFT).$info[$c]."\n";
        }
    }

    public function preparaDownload()
    {
        $data = DateUtil::getDataAtual();
        $nome = "RAIS_".str_replace("/","_",str_replace(" ","_",str_replace("&","e",$this->rais->getRazaoSocial()))).'_'.$data->format('dmYHis').".dec";
        FPA::escreveArquivo($nome,$this->magnetico);
        return FPA::getTempDirectory().'/'.$nome;
        /*
        $path = "..\\files\\RAIS";

        if (!file_exists($path)) {
            mkdir($path, 0777, true);
        }

        $path = realpath($path);
        $caminho = $path.DIRECTORY_SEPARATOR.$nome;
        file_put_contents($caminho, $this->magnetico);

        $arquivo = new \TkFile(realpath($caminho)); 
        $arquivo->download();*/
    }

} 