<?php

namespace HCM\Geral\Controllers;

use Teknisa\Libs\Util\Environment;
use HCM\Geral\Services\CrudService;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\Manager\Doctrine\NameProvider;
use HCM\Util\HCMParameters;

class CrudController {
    const DATABASE_NAME = 'dbname';

    protected $crudService;
    protected $environment;
    protected $dataSourceName;
    protected $dataSourceNameToSave = false;

    public function __construct(HCMParameters $hcmParameters, Environment $environment, CrudService $crudService, NameProvider $nameProvider) {
        $this->hcmParameters = $hcmParameters;
        $this->environment = $environment;
        $this->crudService = $crudService;
        $this->nameProvider = $nameProvider;
    }

    public function checkHistory(DTO\Response $response, $row) {
        
        $primaryKeys = $this->nameProvider->getDataSourceByName($row['saveHistoryTable']['__table_history_name'])->getPrimaryKeyColumns();
        
        
        $condition = array(
            array(
                "columnName" => strtoupper($row['saveHistoryTable']['__table_master_pk']),
                "operator" => "=",
                "value" => $row[strtoupper($row['saveHistoryTable']['__table_master_pk'])]
            ),
            array(
                "columnName" => strtoupper($row['saveHistoryTable']['__table_competenc']),
                "operator" => "=",
                "value" => $row[strtoupper($row['saveHistoryTable']['__table_competenc'])]
            )
        );

        foreach($primaryKeys as $primaryKey){
            if(strtoupper($primaryKey) == "NRORG")
                $condition[] =  array(
                                    "columnName" => "NRORG",
                                    "operator" => "=",
                                    "value" => $this->hcmParameters->getNrorgTrabalho()
                                );

        }
        $filterCriteria = new FilterCriteria($row['saveHistoryTable']['__table_history_name'], $condition);
        $newFilterCriteria = $this->crudService->populateParameterBag($filterCriteria, array());
        $this->crudService->find($response, $newFilterCriteria);
        
        if (count($response->getDataSets()[0]->getRows()) > 0) {
            return true;
        } else {
            return false;
        }
    }

    public function saveCrud(DTO\Request $request, DTO\Response $response) {
        try {
            $verificaEsocial = null;
            foreach($request->getDataSet()->getRows() as $row){
                
                /* função que verifica a existência de envios para o registro
                 * utilizada para quando se alterar a data de inicio de vigêcia de um registro que ja foi enviado para o ESocial
                 * direcionado para as telas: eventos    
                */
                $verificaEsocial = $this->crudService->verificaVigenciaEnvio($row);
                
                if($verificaEsocial){
                
                    $this->dataSourceName = $row["__new_code_pk"];
                    
                    $prevInfo = $this->crudService->getInformacoesPrevias($row);
                    
                    
                    $this->dataSourceNameToSave = $this->crudService->getDataSourceNameToSaveByName($this->dataSourceName);
                    $this->dataSourceName = $this->dataSourceNameToSave ? $this->dataSourceNameToSave : $this->dataSourceName;
                    $rows = $this->crudService->getRowsToSave($request, $this->dataSourceName);
                    
                    $this->crudService->save($this->dataSourceName, $rows);
        
                    $request = $this->crudService->buildDataSetIfRow($request, $this->dataSourceName);
        
                    $currentRow = current($request->getDataSet()->getRows());
        
                    if(isset($currentRow['saveHistoryTable'])) {
        
                        if (!$currentRow['__is_new']) {
                            if (!$this->checkHistory($response, $currentRow)) {
                                // is new history
                                $currentRow['__is_new'] = true;
                            }
                        }
        
                        $tableMasterPK = strtoupper($currentRow['saveHistoryTable']['__table_master_pk']);
                        $newCode = array_filter($this->crudService->getColumnsToReturn(), function ($element) use ($tableMasterPK) {
                            return $element[$tableMasterPK];
                        });
        
                        $this->dataSourceNameToSave = $this->crudService->getDataSourceNameToSaveByName($currentRow['saveHistoryTable']['__table_history_name']);
                        $this->dataSourceName = $this->dataSourceNameToSave ? $this->dataSourceNameToSave : $this->dataSourceName;
                        $currentRow[strtoupper($currentRow['saveHistoryTable']['__table_master_pk'])] = intval($newCode[0][strtoupper($currentRow['saveHistoryTable']['__table_master_pk'])]);
        
                        // set history properties
                        $currentRow['__new_code_pk'] = $currentRow['saveHistoryTable']['__table_history_name'];
                        $currentRow['__table_pk'] = $currentRow['saveHistoryTable']['__table_history_pk'];
                        $currentRow['__columns_to_return'] = $currentRow['saveHistoryTable']['__columns_to_return'];
        
                        $newDataSet = new DataSet($this->dataSourceName, array($currentRow));
                        $newRequest = new \Zeedhi\Framework\DTO\Request\DataSet($newDataSet,
                            $request->getMethod(), $request->getRoutePath(), $request->getUserId());
                        $rows = $this->crudService->getRowsToSave($newRequest, $this->dataSourceName);
                        $this->crudService->save($this->dataSourceName, $rows);
        
                    }
                        
                    //se o registro em questão for um evento, verifica se possui incidências a serem incluídas e as salva se for necessário. Além disso, certas regras são cadastradas automaticamente
                    //a depender do tipo de evento e do tipo de ocorrencia
                    $this->crudService->atualizaDemaisInformacoes($row, $newCode, $prevInfo);
                    
                }
            }
            if($verificaEsocial){
                $response->addDataset(new DataSet('columnsToReturn', $this->crudService->getColumnsToReturn()));
            }else{
                $response->addDataset(new DataSet('verificaVigenciaEnvio', ['ENVIO' => true]));
            }
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $this->dataSourceName = $request->getParameter(self::DATABASE_NAME);
            $filterCriteria = $request->getFilterCriteria();
            $filterCriteria->setDataSourceName($this->dataSourceName);
            $filterCriteria = $this->crudService->getFilterCriteriaWithNrOrg($filterCriteria);
            $newFilterCriteria = $this->crudService->getPopulatedFilterCriteria($filterCriteria, array());
            $this->crudService->find($response, $newFilterCriteria);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function delete(DTO\Request $request, DTO\Response $response) {
        try {
            $this->dataSourceName = $request->getParameter(self::DATABASE_NAME);
            $this->dataSourceName = $this->crudService->getDataSourceNameToSaveByName($this->dataSourceName);
            $request = $this->crudService->buildDataSetIfRow($request, $this->dataSourceName);
            $rows = $this->crudService->getRowsToDelete($request, $this->dataSourceName);
            $dataSet = new DataSet($this->dataSourceName, (array)$rows);
            $this->crudService->delete($response, $dataSet);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
}