<?php
/**
 * Created by PhpStorm.
 * User: felipesantos
 * Date: 18/08/2017
 * Time: 11:09
 */

namespace HCM\Geral\Controllers;

use Doctrine\ORM\EntityManager;
use HCM\Geral\Logic\ESocialLogic;
use HCM\Geral\Services\ESocialService;
use HCM\Geral\Services\EsoSimplificadoService;
use HCM\Util\HCMParameters;
use HCM\Util\Messages;
use HCM\Util\Repositories;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;

class EsoSimplificadoController extends Crud {

    protected $dataSourceName = '';

    protected $dtsGetEsocadastro = 'getEsocadastro';
    protected $dtsSetEsocadastro = 'setEsocadastro';
    protected $dtsGetEsonaoperiodico = 'getEsonaoperiodico';
    protected $dtsSetEsonaoperiodico = 'setEsonaoperiodico';
    protected $dtsGetEsoperiodo = 'getEsoperiodo';
    protected $dtsGetEsoperiodico = 'getEsoperiodico';
    protected $dtsSetEsoperiodico = 'setEsoperiodico';

    protected $parameterBagColumns = array('P_NRORG', 'P_NRORG_PADRAO', 'P_DTMESCOMPETENC', 'P_NRTPAMBIENTE', 'P_NRESTRUTURAM', 'P_SST');

    protected $camposChave = array(
        'S-1000' => 'NRESTRUTURAM',
        'S-1005' => 'NRESTRUTESTAB',
        'S-1010' => 'NREVENTOM',
        'S-1020' => 'NRESTRUTTOMAD',
        'S-1070' => 'NRPROCESSADMJUD'
    );
    
    // Array que armazena as mensagens geradas na rotina 'processEnvio'. É organizada da seguinte forma: 'nomeMensagem' => 'valoresAssociados'
    protected $mensagensProcessEnvio = array();

    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, EntityManager $entityManager, HCMParameters $hcmParameters, 
                                 EsoSimplificadoService $esoSimplificadoService, ESocialService $eSocialService){
        $this->parameterBag = $parameterBag;
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->esoSimplificadoService = $esoSimplificadoService;
        $this->eSocialService = $eSocialService;
        
        parent::__construct($dataSourceManager);
    }
    
    public function getEsocadastro(DTO\Request\Filter $request, DTO\Response $response){
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dtsGetEsocadastro);
        $filterData->setPageSize(99999);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }

    public function setEsocadastro(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            $this->dataSourceName = $this->dtsSetEsocadastro;
            
            foreach ($request->getDataSet()->getRows() as &$row) {
                if ($row['__is_new']) {
                    $row['NRORG'] = $this->hcmParameters->getNrorgTrabalho();
                    
                    $row['IDATIVO'] = isset($row['IDATIVO']) ? $row['IDATIVO'] : 'S';
                    $row['IDSTATUS'] = isset($row['IDSTATUS']) ? $row['IDSTATUS'] : 'P';
                    $row['IDEVENTO'] = isset($row['IDEVENTO']) ? $row['IDEVENTO'] : null;
                    $row['DTENVIO'] = isset($row['DTENVIO']) ? $row['DTENVIO'] : null;
                    $row['DTRESPOSTA'] = isset($row['DTRESPOSTA']) ? $row['DTRESPOSTA'] : null;
                    $row['DTPROCESSAMENTO'] = isset($row['DTPROCESSAMENTO']) ? $row['DTPROCESSAMENTO'] : null;
                    $row['NRPROTOCOLO'] = isset($row['NRPROTOCOLO']) ? $row['NRPROTOCOLO'] : null;
                    $row['NRRECIBO'] = isset($row['NRRECIBO']) ? $row['NRRECIBO'] : null;
                    $row['CDERRO'] = isset($row['CDERRO']) ? $row['CDERRO'] : null;
                    $row['DSDIRXMLENV'] = isset($row['DSDIRXMLENV']) ? $row['DSDIRXMLENV'] : null;
                    $row['DSDIRXMLRETENV'] = isset($row['DSDIRXMLRETENV']) ? $row['DSDIRXMLRETENV'] : null;
                    $row['DSDIRXMLRETPRO'] = isset($row['DSDIRXMLRETPRO']) ? $row['DSDIRXMLRETPRO'] : null;
                    $row['DSOBSERVACAO'] = isset($row['DSOBSERVACAO']) ? $row['DSOBSERVACAO'] : null;
                    $row['DSOBSERVACAO2'] = isset($row['DSOBSERVACAO2']) ? $row['DSOBSERVACAO2'] : null;

                    $campoChave = $this->camposChave[$row['NMEVENTO']];
                    if ($row['NMEVENTO'] == 'S-1000') {
                        $row['NRCHAVE'] = [$row[$campoChave]];
                    } else {
                        $row['NRCHAVE'] = empty($row[$campoChave]) ? [null] : $row[$campoChave];
                       
                    }
                    foreach ($row['NRCHAVE'] as $nrchave) {
                        $row[$campoChave] = $nrchave;
                        
                        $arrItens = $this->esoSimplificadoService->getItensParaEnvioEvento($row['NMEVENTO'], $row['IDGRUPO'], $row);
                        if (empty($arrItens)) {
                            $this->addMensagemProcessEnvio(Messages::HCM09000_ESO_ENVIOS_NOT_FOUND_ERROR, $row['NMEVENTO']);
                            break;
                        }
                        
                        foreach($arrItens as $item) {
                            $row['NRCHAVE'] = $item['NRCHAVE'];
                            $row['NRTABELA'] = isset($item['NRTABELA']) ? $item['NRTABELA'] : '';
                            $row['IDOPERACAO'] = isset($item['IDOPERACAO']) ? $item['IDOPERACAO'] : 'I';
                            $row['DTMESCOMPETENC'] = $item['DTMESCOMPETENC'];
                            try {
                                $this->esoSimplificadoService->beforeInsertCadastro(
                                    $row['NRORG'], $row['NRTPAMBIENTE'], $row['NRESTRUTURAM'], $row['CDCNPJEMPREGADOR'], $row['DTMESCOMPETENC'], $row['NMEVENTO'], $row['NRCHAVE'], $row['NRTABELA'], $row['IDOPERACAO']
                                );
                            } catch(\Exception $e) {
                                if ($e->getCode() == Messages::ALERT_MESSAGE_CODE) {
                                    if($e->getMessage() == Messages::HCM09000_ESO_UNIQUE_ENVIO_ERROR){
                                        $this->addMensagemProcessEnvio(Messages::HCM09000_ESO_UNIQUE_ENVIO_ERROR, $row['NMEVENTO'] . ' - ' . $item['NRCHAVE']);
                                    } else {
                                        $response->addMessage(new DTO\Response\Message($e->getMessage()), DTO\Response\Message::TYPE_WARNING);
                                    }
                                    continue;
                                } else {
                                    throw $e;
                                }
                            }
                            
                            if (array_key_exists('NRENVIO', $row)) {
                                if ($row['NRENVIO'] === '') {
                                    $row['NRENVIO'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'ESO_CADASTRO', 1, 12, true);
                                }
                            } else {
                                $row['NRENVIO'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'ESO_CADASTRO', 1, 12, true);
                            }
                            
                            parent::save($request, $response);
                            
                            unset($row['NRENVIO']);
                        }
                    }
                } else {
                    parent::save($request, $response);
                }
            }
            
            if($this->mensagensProcessEnvio){
                $response->addMessage(new DTO\Response\Message($this->getMensagensProcessEnvio(), DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function deleteEsocadastro(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            $retorno = false;
            foreach ($request->getDataSet()->getRows() as &$row) {
                //$this->esoSimplificadoService->beforeDeleteEvento($row, Repositories::ESO_CADASTRO);
                $this->eSocialService->deleteDadosEnvio($row);
                $retorno = $this->esoSimplificadoService->deleteEvento($row['NRORG'], $row['NRENVIO'], Repositories::ESO_CADASTRO);
            }
            if($retorno){
                $response->addNotification(new DTO\Response\Notification('deleteEsocadastro', DTO\Response\Notification::TYPE_SUCCESS));
            } else {
                $response->addNotification(new DTO\Response\Notification('deleteEsocadastro', DTO\Response\Notification::TYPE_ERROR));
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getEsonaoperiodico(DTO\Request\Filter $request, DTO\Response $response){
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dtsGetEsonaoperiodico);
        $filterData->setPageSize(99999);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }

    public function setEsonaoperiodico(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            $this->dataSourceName = $this->dtsSetEsonaoperiodico;
            
            foreach ($request->getDataSet()->getRows() as &$row) {
                if ($row['__is_new']) {
                    $row['NRORG'] = $this->hcmParameters->getNrorgTrabalho();
                    
                    $row['IDATIVO'] = isset($row['IDATIVO']) ? $row['IDATIVO'] : 'S';
                    $row['IDSTATUS'] = isset($row['IDSTATUS']) ? $row['IDSTATUS'] : 'P';
                    $row['IDEVENTO'] = isset($row['IDEVENTO']) ? $row['IDEVENTO'] : null;
                    $row['DTENVIO'] = isset($row['DTENVIO']) ? $row['DTENVIO'] : null;
                    $row['DTRESPOSTA'] = isset($row['DTRESPOSTA']) ? $row['DTRESPOSTA'] : null;
                    $row['DTPROCESSAMENTO'] = isset($row['DTPROCESSAMENTO']) ? $row['DTPROCESSAMENTO'] : null;
                    $row['NRPROTOCOLO'] = isset($row['NRPROTOCOLO']) ? $row['NRPROTOCOLO'] : null;
                    $row['NRRECIBO'] = isset($row['NRRECIBO']) ? $row['NRRECIBO'] : null;
                    $row['CDERRO'] = isset($row['CDERRO']) ? $row['CDERRO'] : null;
                    $row['DSDIRXMLENV'] = isset($row['DSDIRXMLENV']) ? $row['DSDIRXMLENV'] : null;
                    $row['DSDIRXMLRETENV'] = isset($row['DSDIRXMLRETENV']) ? $row['DSDIRXMLRETENV'] : null;
                    $row['DSDIRXMLRETPRO'] = isset($row['DSDIRXMLRETPRO']) ? $row['DSDIRXMLRETPRO'] : null;
                    $row['DSDIRXMLRETTOT'] = isset($row['DSDIRXMLRETTOT']) ? $row['DSDIRXMLRETTOT'] : null;
                    $row['DSOBSERVACAO'] = isset($row['DSOBSERVACAO']) ? $row['DSOBSERVACAO'] : null;
                    $row['DSOBSERVACAO2'] = isset($row['DSOBSERVACAO2']) ? $row['DSOBSERVACAO2'] : null;
                    $row['NRENVIOEXCL'] = isset($row['NRENVIOEXCL']) ? $row['NRENVIOEXCL'] : null;
                    $row['VRBASEMENSAL'] = isset($row['VRBASEMENSAL']) ? $row['VRBASEMENSAL']: null;
                    $row['VRBASE13'] = isset($row['VRBASE13']) ? $row['VRBASE13']: null;
                    $row['VRVALORMENSAL'] = isset($row['VRVALORMENSAL']) ? $row['VRVALORMENSAL']: null;
                    $row['VRVALOR13'] = isset($row['VRVALOR13']) ? $row['VRVALOR13']: null;
                    $row['VRVALORMATERMENSAL'] = isset($row['VRVALORMATERMENSAL']) ? $row['VRVALORMATERMENSAL']: null;
                    $row['VRVALORMATER13'] = isset($row['VRVALORMATER13']) ? $row['VRVALORMATER13']: null;
                    $row['VRSALFAMILIA'] = isset($row['VRSALFAMILIA']) ? $row['VRSALFAMILIA']: null;
                    $row['VRSALFAMILIA13'] = isset($row['VRSALFAMILIA13']) ? $row['VRSALFAMILIA13']: null;
                    $row['VRCALCULADO'] = isset($row['VRCALCULADO']) ? $row['VRCALCULADO']: null;
                    $row['VRDESCONTADO'] = isset($row['VRDESCONTADO']) ? $row['VRDESCONTADO']: null;
                    $row['NRESTRUTLOTACAO'] = isset($row['NRESTRUTLOTACAO']) ? $row['NRESTRUTLOTACAO']: null;

                    $row['NRVINCULOM'] = empty($row['NRVINCULOM']) ? [null] : $row['NRVINCULOM'];
                    
                    $esoParametro = $this->entityManager->getRepository(Repositories::ESO_PARAMETRO)->findOneBy(
                        array('nrorg'=>$row['NRORG'], 'nrestruturam'=>$row['NRESTRUTURAM'])
                    );
                    $row['DTREFNAOPERIOD'] = $esoParametro->getDtrefnaoperiod() ? $esoParametro->getDtrefnaoperiod()->format('d/m/Y') : null;
                    
                    foreach ($row['NRVINCULOM'] as $index => $nrvinculom) {
                        $row['NRVINCULOM'] = $nrvinculom;
                        $row['NMVINCULOM'] = empty($row['NMVINCULOM_LIST']) ? null : $row['NMVINCULOM_LIST'][$index];
                        $row['NRPESSOA'] = empty($row['NRPESSOA_LIST']) ? null : $row['NRPESSOA_LIST'][$index];
                        $row['DTADMISSAOVINC'] = empty($row['DTADMISSAOVINC_LIST']) ? null : $row['DTADMISSAOVINC_LIST'][$index];
                        $row['DTRESCISAOVINC'] = empty($row['DTRESCISAOVINC_LIST']) ? null : $row['DTRESCISAOVINC_LIST'][$index];
                    
                        $arrItens = $this->esoSimplificadoService->getItensParaEnvioEvento($row['NMEVENTO'], $row['IDGRUPO'], $row);
                        if (empty($arrItens)) {
                            $this->addMensagemProcessEnvio(Messages::HCM09000_ESO_ENVIOS_NOT_FOUND_ERROR, $row['NMEVENTO']);
                            break;
                        }
                        
                        foreach($arrItens as $item) {
                            $row['NRCHAVE'] = $item['NRCHAVE'];
                            $row['NRTABELA'] = isset($item['NRTABELA']) ? $item['NRTABELA'] : '';
                            $row['IDOPERACAO'] = isset($item['IDOPERACAO']) ? $item['IDOPERACAO'] : 'I';
                            $row['DTMESCOMPETENC'] = $item['DTMESCOMPETENC'];
                            $row['NRVINCULOM'] = $item['NRVINCULOM'];
                
                            try {
                                $this->esoSimplificadoService->beforeInsertNaoPeriodico(
                                    $row['NRORG'], $row['NRTPAMBIENTE'], $row['NRESTRUTURAM'], $row['CDCNPJEMPREGADOR'], $row['NRVINCULOM'], $row['DTMESCOMPETENC'], $row['NMEVENTO'], $row['NRCHAVE'], $row['NRTABELA'], $row['IDOPERACAO']
                                );
                            } catch(\Exception $e) {
                                if ($e->getCode() == Messages::ALERT_MESSAGE_CODE) {
                                    if($e->getMessage() == Messages::HCM09000_ESO_UNIQUE_ENVIO_ERROR){
                                        $this->addMensagemProcessEnvio(Messages::HCM09000_ESO_UNIQUE_ENVIO_ERROR, $row['NMEVENTO'] . ' - ' . $row['NRCHAVE']);
                                    } else {
                                        $response->addMessage(new DTO\Response\Message($e->getMessage()), DTO\Response\Message::TYPE_WARNING);
                                    }
                                    continue;
                                } else {
                                    throw $e;
                                }
                            }
                            
                            if (array_key_exists('NRENVIO', $row)) {
                                if ($row['NRENVIO'] === '') {
                                    $row['NRENVIO'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'ESO_NAOPERIODICO', 1, 12, true);
                                }
                            } else {
                                $row['NRENVIO'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'ESO_NAOPERIODICO', 1, 12, true);
                            }
                            
                            parent::save($request, $response);
                            
                            unset($row['NRENVIO']);
                        }
                    }
                } else {
                    parent::save($request, $response);
                }
            }
            
            if($this->existemMensagensProcessEnvio()){
                $response->addMessage(new DTO\Response\Message($this->getMensagensProcessEnvio(), DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function deleteEsonaoperiodico(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            $retorno = false;
            foreach ($request->getDataSet()->getRows() as &$row) {
                $this->esoSimplificadoService->beforeDeleteEvento($row, Repositories::ESO_NAOPERIODICO);
                $this->eSocialService->deleteDadosEnvio($row);
                $retorno = $this->esoSimplificadoService->deleteEvento($row['NRORG'], $row['NRENVIO'], Repositories::ESO_NAOPERIODICO);
            }
            if($retorno){
                $response->addNotification(new DTO\Response\Notification('deleteEsonaoperiodico', DTO\Response\Notification::TYPE_SUCCESS));
            } else {
                $response->addNotification(new DTO\Response\Notification('deleteEsonaoperiodico', DTO\Response\Notification::TYPE_ERROR));
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getEsoperiodo(DTO\Request\Filter $request, DTO\Response $response){
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dtsGetEsoperiodo);
        $filterData->setPageSize(99999);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function getEsoperiodico(DTO\Request\Filter $request, DTO\Response $response){
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dtsGetEsoperiodico);
        $filterData->setPageSize(99999);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }

    public function setEsoperiodico(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            $this->dataSourceName = $this->dtsSetEsoperiodico;
            
            foreach ($request->getDataSet()->getRows() as &$row) {
                if ($row['__is_new']) {
                    $row['NRORG'] = $this->hcmParameters->getNrorgTrabalho();
                    
                    $row['IDATIVO'] = isset($row['IDATIVO']) ? $row['IDATIVO'] : 'S';
                    $row['IDSTATUS'] = isset($row['IDSTATUS']) ? $row['IDSTATUS'] : 'P';
                    $row['IDEVENTO'] = isset($row['IDEVENTO']) ? $row['IDEVENTO'] : null;
                    $row['DTENVIO'] = isset($row['DTENVIO']) ? $row['DTENVIO'] : null;
                    $row['DTRESPOSTA'] = isset($row['DTRESPOSTA']) ? $row['DTRESPOSTA'] : null;
                    $row['DTPROCESSAMENTO'] = isset($row['DTPROCESSAMENTO']) ? $row['DTPROCESSAMENTO'] : null;
                    $row['NRPROTOCOLO'] = isset($row['NRPROTOCOLO']) ? $row['NRPROTOCOLO'] : null;
                    $row['NRRECIBO'] = isset($row['NRRECIBO']) ? $row['NRRECIBO'] : null;
                    $row['CDERRO'] = isset($row['CDERRO']) ? $row['CDERRO'] : null;
                    $row['DSDIRXMLENV'] = isset($row['DSDIRXMLENV']) ? $row['DSDIRXMLENV'] : null;
                    $row['DSDIRXMLRETENV'] = isset($row['DSDIRXMLRETENV']) ? $row['DSDIRXMLRETENV'] : null;
                    $row['DSDIRXMLRETPRO'] = isset($row['DSDIRXMLRETPRO']) ? $row['DSDIRXMLRETPRO'] : null;
                    $row['DSDIRXMLRETTOT'] = isset($row['DSDIRXMLRETTOT']) ? $row['DSDIRXMLRETTOT'] : null;
                    $row['DSOBSERVACAO'] = isset($row['DSOBSERVACAO']) ? $row['DSOBSERVACAO'] : null;
                    $row['DSOBSERVACAO2'] = isset($row['DSOBSERVACAO2']) ? $row['DSOBSERVACAO2'] : null;
                    $row['NRENVIOEXCL'] = isset($row['NRENVIOEXCL']) ? $row['NRENVIOEXCL'] : null;
                    $row['VRBASEMENSAL'] = isset($row['VRBASEMENSAL']) ? $row['VRBASEMENSAL']: null;
                    $row['VRBASE13'] = isset($row['VRBASE13']) ? $row['VRBASE13']: null;
                    $row['VRVALORMENSAL'] = isset($row['VRVALORMENSAL']) ? $row['VRVALORMENSAL']: null;
                    $row['VRVALOR13'] = isset($row['VRVALOR13']) ? $row['VRVALOR13']: null;
                    $row['VRVALORMATERMENSAL'] = isset($row['VRVALORMATERMENSAL']) ? $row['VRVALORMATERMENSAL']: null;
                    $row['VRVALORMATER13'] = isset($row['VRVALORMATER13']) ? $row['VRVALORMATER13']: null;
                    $row['VRSALFAMILIA'] = isset($row['VRSALFAMILIA']) ? $row['VRSALFAMILIA']: null;
                    $row['VRSALFAMILIA13'] = isset($row['VRSALFAMILIA13']) ? $row['VRSALFAMILIA13']: null;
                    $row['VRCALCULADO'] = isset($row['VRCALCULADO']) ? $row['VRCALCULADO']: null;
                    $row['VRDESCONTADO'] = isset($row['VRDESCONTADO']) ? $row['VRDESCONTADO']: null;
                    $row['NRESTRUTLOTACAO'] = isset($row['NRESTRUTLOTACAO']) ? $row['NRESTRUTLOTACAO']: null;
                    
                    $row['NRPESSOA'] = empty($row['NRPESSOA']) ? [null] : $row['NRPESSOA'];
                    
                    foreach ($row['NRPESSOA'] as $index => $nrpessoa) {
                        $row['NRPESSOA'] = $nrpessoa;
                    
                        $arrItens = $this->esoSimplificadoService->getItensParaEnvioEvento($row['NMEVENTO'], $row['IDGRUPO'], $row);
                        if (empty($arrItens)) {
                            $this->addMensagemProcessEnvio(Messages::HCM09000_ESO_ENVIOS_NOT_FOUND_ERROR, $row['NMEVENTO']);
                            break;
                        }
                    
                        foreach($arrItens as $item) {
                            $row['NRCHAVE']         = $item['NRCHAVE'];
                            $row['NRTABELA']        = isset($item['NRTABELA']) ? $item['NRTABELA'] : '';
                            $row['IDOPERACAO']      = isset($item['IDOPERACAO']) ? $item['IDOPERACAO'] : 'I';
                            $row['DTMESCOMPETENC']  = $item['DTMESCOMPETENC'];
                            $row['NRPESSOA']        = isset($item['NRPESSOA']) ? $item['NRPESSOA'] : '';
                
                            try {
                                $this->esoSimplificadoService->beforeInsertPeriodico(
                                    $row['NRORG'], $row['NRTPAMBIENTE'], $row['NRESTRUTURAM'], $row['CDCNPJEMPREGADOR'], $row['NRPESSOA'], $row['DTMESCOMPETENC'], $row['NMEVENTO'], $row['NRCHAVE'], $row['NRTABELA'], $row['IDOPERACAO']
                                );
                            } catch(\Exception $e) {
                                if ($e->getCode() == Messages::ALERT_MESSAGE_CODE) {
                                    if($e->getMessage() == Messages::HCM09000_ESO_UNIQUE_ENVIO_ERROR){
                                        $this->addMensagemProcessEnvio(Messages::HCM09000_ESO_UNIQUE_ENVIO_ERROR, $row['NMEVENTO']);
                                    } else {
                                        $response->addMessage(new DTO\Response\Message($e->getMessage()), DTO\Response\Message::TYPE_WARNING);
                                    }
                                    continue;
                                } else {
                                    throw $e;
                                }
                            }
                            
                            if (array_key_exists('NRENVIO', $row)) {
                                if ($row['NRENVIO'] === '') {
                                    $row['NRENVIO'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'ESO_PERIODICO', 1, 12, true);
                                }
                            } else {
                                $row['NRENVIO'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'ESO_PERIODICO', 1, 12, true);
                            }
                            
                            parent::save($request, $response);
                            
                            unset($row['NRENVIO']);
                        }
                    }
                } else {
                    parent::save($request, $response);
                }
            }
            
            if($this->existemMensagensProcessEnvio()){
                $response->addMessage(new DTO\Response\Message($this->getMensagensProcessEnvio(), DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function deleteEsoperiodico(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            $retorno = false;
            foreach ($request->getDataSet()->getRows() as &$row) {
                $this->esoSimplificadoService->beforeDeleteEvento($row, Repositories::ESO_PERIODICO);
                $this->eSocialService->deleteDadosEnvio($row);
                if ($row['NMEVENTO'] == 'S-3000') {
                    $retorno = $this->esoSimplificadoService->deleteEvento($row['NRORG'], $row['NRENVIO'], Repositories::ESO_NAOPERIODICO);
                } else {
                    $retorno = $this->esoSimplificadoService->deleteEvento($row['NRORG'], $row['NRENVIO'], Repositories::ESO_PERIODICO);
                }
            }
            if($retorno){
                $response->addNotification(new DTO\Response\Notification('deleteEsoperiodico', DTO\Response\Notification::TYPE_SUCCESS));
            } else {
                $response->addNotification(new DTO\Response\Notification('deleteEsoperiodico', DTO\Response\Notification::TYPE_ERROR));
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /*-----Cadastro-----*/
    public function enviarEventoCadastro(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            foreach ($request->getDataSet()->getRows() as $row) {
                $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
                $msgRetorno = $logic->enviarEventoCadastro($row);
                $msgValidacao = $logic->getMessages();
            }
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('enviarEventoCadastro', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Envio de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function consultarProtocoloCadastro(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            foreach ($request->getDataSet()->getRows() as $row) {
                $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
                $msgRetorno = $logic->consultarProtocoloCadastro($row);
                $msgValidacao = $logic->getMessages();
            }
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('consultarProtocoloCadastro', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Consulta de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function retificarEventoCadastro(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            foreach ($request->getDataSet()->getRows() as $row) {
                $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
                $msgRetorno = $logic->retificarEventoCadastro($row);
                $msgValidacao = $logic->getMessages();
            }
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('retificarEventoCadastro', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Retificação de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function excluirEventoCadastro(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            foreach ($request->getDataSet()->getRows() as $row) {
                $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
                $msgRetorno = $logic->excluirEventoCadastro($row);
                $msgValidacao = $logic->getMessages();
            }
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('excluirEventoCadastro', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Exclusão de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }

    public function enviarLoteEventoCadastro(DTO\Request\Row $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            $row = $request->getRow();
            
            $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
            $msgRetorno = $logic->enviarLoteEventoCadastro($row['EVENTOS']);
            $msgValidacao = $logic->getMessages();
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('enviarLoteEventoCadastro', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Envio de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function envioAutomaticoCadastro(DTO\Request\Row $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            $row = $request->getRow();
            $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
            $msgRetorno = $logic->envioAutomaticoCadastro($row['NMEVENTO'], $row['IDSTATUS']);
            $msgValidacao = $logic->getMessages();
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('envioAutomaticoCadastro', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Envio de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function consultaAutomaticaCadastro(DTO\Request\Row $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            $row = $request->getRow();
            $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
            $msgRetorno = $logic->consultaAutomaticaCadastro($row['NMEVENTO'], $row['IDSTATUS']);
            $msgValidacao = $logic->getMessages();
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('consultaAutomaticaCadastro', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Consulta de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function exclusaoEmpregador(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            foreach ($request->getDataSet()->getRows() as $row) {
                $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
                $msgRetorno = $logic->exclusaoEmpregador($row);
                $msgValidacao = $logic->getMessages();
            }
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('exclusaoEmpregador', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Envio de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    /*-----Não Periodicos-----*/
    public function enviarEventoNaoPeriodico(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            $msgRetorno = null;
            $msgValidacao = array();
            $eventosPendentes = array();
            $posterior = null;
            
            foreach ($request->getDataSet()->getRows() as $row) {
                $verificaPendentes = (isset($row['VERIFICAPENDENTES']) ? $row['VERIFICAPENDENTES'] : true);
                if ($verificaPendentes && ($row['NMEVENTO'] == 'S-2299' || $row['NMEVENTO'] == 'S-2399')) {
                    $posterior = $this->esoSimplificadoService->verificaEventoDataPosterior($row);
                    if($posterior){
                        $msgValidacao[] = array(
                            'NMEVENTO' => $row['NMEVENTO'],
                            'NRCHAVE' => $row['NRCHAVE'],
                            'MSG' => "Existem eventos com data posterior para o vinculo ".$row['NRVINCULOM'],
                            'TYPE' => 'E',
                        );
                    }
                    $pendentes = $this->esoSimplificadoService->vefificaEventosAfastamentoPendentes($row['NRORG'], $row['NRESTRUTURAM'], $row['NRVINCULOM']);
                    foreach ($pendentes as $evento) {
                        $eventoArr = $evento->toArray();
                        $eventoArr['NMVINCULOM'] = $row['NMVINCULOM'];
                        $eventoArr['NRCPFPESSOA'] = $row['NRCPFPESSOA'];
                        $eventoArr['DTMESCOMPETENC'] = $evento->getDtmescompetenc()->format('d/m/Y H:i:s');
                        $eventosPendentes[] = $eventoArr;
                    }
                }
                
                if (count($eventosPendentes) > 0 || $posterior) {
                    continue;
                } else {
                    $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
                    $msgRetorno = $logic->enviarEventoNaoPeriodico($row);
                    $msgValidacao = $logic->getMessages();
                }
            }
            
            if (count($eventosPendentes) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('eventosPendentes', $eventosPendentes));
                if (is_null($msgRetorno)) {
                    $msgRetorno = "Existem eventos pendentes. Favor verificar.";
                }
            }
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('enviarEventoNaoPeriodico', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Envio de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function consultarProtocoloNaoPeriodico(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            foreach ($request->getDataSet()->getRows() as $row) {
                $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
                $msgRetorno = $logic->consultarProtocoloNaoPeriodico($row);
                $msgValidacao = $logic->getMessages();
            }
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('consultarProtocoloNaoPeriodico', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Consulta de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function retificarEventoNaoPeriodico(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            foreach ($request->getDataSet()->getRows() as $row) {
                $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
                $msgRetorno = $logic->retificarEventoNaoPeriodico($row);
                $msgValidacao = $logic->getMessages();
            }
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('retificarEventoNaoPeriodico', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Retificação de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function excluirEventoNaoPeriodico(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            foreach ($request->getDataSet()->getRows() as $row) {
                if(isset($row['NRESTRUTLEGAL'])){
                    $row['NRESTRUTURAM'] = $row['NRESTRUTLEGAL'];
                    $paramESocial        = $this->eSocialService->getParamESocial($row['NRESTRUTURAM']);
                    if ($paramESocial) {
                        $row['NRTPAMBIENTE']      = $paramESocial['NRTPAMBIENTE'];
                        $row['CDCNPJEMPREGADOR']  = $paramESocial['CDCNPJESTRUT'];
                        $row['NRENVIO']           = $this->esoSimplificadoService->findNrEnvioAdmissao($row['NRORG'], $row['NRTPAMBIENTE'], $row['CDCNPJEMPREGADOR'], $row['NRVINCULOM'], $this->hcmParameters->getDtCompetencia());
                        if( $row['NRENVIO'] == null){
                           $response->addMessage(new DTO\Response\Message("Exclusão de evento não disponível. Não foram encontrados envio dos eventos S-2200 ou S-2300 para o vínculo ".$row['NMVINCULOM']."." , DTO\Response\Message::TYPE_WARNING));
                           return;
                       }
                    }
                }
                $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
                $msgRetorno = $logic->excluirEventoNaoPeriodico($row);
                $msgValidacao = $logic->getMessages();
            }
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('excluirEventoNaoPeriodico', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Exclusão de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }

    public function enviarLoteEventoNaoPeriodico(DTO\Request\Row $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            $row = $request->getRow();
            
            $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
            $msgRetorno = $logic->enviarLoteEventoNaoPeriodico($row['EVENTOS']);
            $msgValidacao = $logic->getMessages();
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('enviarLoteEventoNaoPeriodico', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Envio de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function envioAutomaticoNaoPeriodico(DTO\Request\Row $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            $row = $request->getRow();
            
            $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
            $msgRetorno = $logic->envioAutomaticoNaoPeriodico($row['NMEVENTO'], $row['IDSTATUS']);
            $msgValidacao = $logic->getMessages();
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('envioAutomaticoNaoPeriodico', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Envio de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function consultaAutomaticaNaoPeriodico(DTO\Request\Row $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            $row = $request->getRow();
            $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
            $msgRetorno = $logic->consultaAutomaticaNaoPeriodico($row['NMEVENTO'], $row['IDSTATUS']);
            $msgValidacao = $logic->getMessages();
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('consultaAutomaticaNaoPeriodico', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Consulta de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function getNaoPeriodicosPendentes(DTO\Request\Row $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            $row = $request->getRow();
            
            $naoperiodicos = $this->esoSimplificadoService->getNaoPeriodicosPendentes($this->hcmParameters->getNrorg(), $this->hcmParameters->getDtCompetencia(), $row['NRVINCULOMLIST'], $row['NMEVENTOLIST']);
            
            if (count($naoperiodicos) > 0) {
                $dataset = array();
                foreach ($naoperiodicos as $envio) {
                    $dataset[] = $envio->toArray();
                }
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('naoPeriodicosPendentes', $dataset));
            } else {
                $response->addMessage(new DTO\Response\Message("Não foram encontrados eventos pendentes"), DTO\Response\Message::TYPE_SUCCESS);
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    /*-----Periodicos-----*/
    public function enviarEventoPeriodico(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            foreach ($request->getDataSet()->getRows() as $row) {
                $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
                $msgRetorno = $logic->enviarEventoPeriodico($row);
                $msgValidacao = $logic->getMessages();
            }
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('enviarEventoPeriodico', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Envio de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function consultarProtocoloPeriodico(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            foreach ($request->getDataSet()->getRows() as $row) {
                $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
                $msgRetorno = $logic->consultarProtocoloPeriodico($row);
                $msgValidacao = $logic->getMessages();
            }
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('consultarProtocoloPeriodico', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Consulta de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function retificarEventoPeriodico(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            foreach ($request->getDataSet()->getRows() as $row) {
                $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
                $msgRetorno = $logic->retificarEventoPeriodico($row);
                $msgValidacao = $logic->getMessages();
            }
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('retificarEventoPeriodico', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Retificação de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function excluirEventoPeriodico(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            foreach ($request->getDataSet()->getRows() as $row) {
                $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
                $msgRetorno = $logic->excluirEventoPeriodico($row);
                $msgValidacao = $logic->getMessages();
            }
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('excluirEventoPeriodico', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Exclusão de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }

    public function enviarLoteEventoPeriodico(DTO\Request\Row $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            $row = $request->getRow();
            
            $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
            $msgRetorno = $logic->enviarLoteEventoPeriodico($row['EVENTOS']);
            $msgValidacao = $logic->getMessages();
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('enviarLoteEventoPeriodico', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Envio de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function envioAutomaticoPeriodico(DTO\Request\Row $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            $row = $request->getRow();
            $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
            $msgRetorno = $logic->envioAutomaticoPeriodico($row['NMEVENTO'], $row['IDSTATUS']);
            $msgValidacao = $logic->getMessages();
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('envioAutomaticoPeriodico', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Envio de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function consultaAutomaticaPeriodico(DTO\Request\Row $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            $row = $request->getRow();
            $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
            $msgRetorno = $logic->consultaAutomaticaPeriodico($row['NMEVENTO'], $row['IDSTATUS']);
            $msgValidacao = $logic->getMessages();
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('consultaAutomaticaPeriodico', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Consulta de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }

    public function fechamentoEsoSimplificado(DTO\Request\Row $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            $row = $request->getRow();
            $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
            $msgRetorno = $logic->fechamentoEsoSimplificado($row);
            $msgValidacao = $logic->getMessages();
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('fechamentoEsoSimplificado', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Envio de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function reaberturaEsoSimplificado(DTO\Request\Row $request, DTO\Response $response) {
        try {
            ini_set('memory_limit', '2048M');
            set_time_limit(0);
            
            $row = $request->getRow();
            $logic = new ESocialLogic($this->entityManager, $this->hcmParameters, $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
            $msgRetorno = $logic->reaberturaEsoSimplificado($row);
            $msgValidacao = $logic->getMessages();
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('reaberturaEsoSimplificado', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Envio de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }

    public function getXmlEsoSimplificado(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $nrorg = $this->hcmParameters->getNrorgTrabalho();
            $xmlFile = null;
            $idEvento = null;
            $dsDirXml = null;
            foreach ($request->getFilterCriteria()->getConditions() as $condition) {
                if ($condition['columnName'] == 'P_XMLFILE') {
                    $xmlFile = $this->processConditionValue($condition);
                }
                if ($condition['columnName'] == 'P_IDEVENTO') {
                    $idEvento = $this->processConditionValue($condition);
                }
                if ($condition['columnName'] == 'P_DSDIRXML') {
                    $dsDirXml = $this->processConditionValue($condition);
                }
                if ($condition['columnName'] == 'P_NRTPAMBIENTE') {
                    $nrTpAmbiente = $this->processConditionValue($condition);
                }
                if ($condition['columnName'] == 'P_IDGRUPO') {
                    $idGrupo = $this->processConditionValue($condition);
                }
                if ($condition['columnName'] == 'P_CDCNPJESTRUT') {
                    $cdCnpjEstrut = $this->processConditionValue($condition);
                }
            }
            // Alteração temporária para ler os arquivos no servidor AWS
            $dsDirXmlFilesPath = 
                ($nrTpAmbiente == 1 ? 'Producao' : 'ProducaoRestrita') . "/" .
                ($idGrupo == 'P' ? 'Periodicos' : ($idGrupo == 'N' ? 'NaoPeriodicos' : 'Cadastros')) . "/" .
                $cdCnpjEstrut . "/" .
                ($xmlFile == 'envio' ? 'Envio' : ($xmlFile == 'retorno' ? 'RetornoEnvio' : ($xmlFile == 'consulta' ? 'RetornoProcessamento' : ($xmlFile == 'total' ? 'Totalizador' : '')))). "/" .
                $dsDirXml;
            $xml = $this->eSocialService->getXmlFiles($nrorg, $xmlFile, $idEvento, $dsDirXml, $dsDirXmlFilesPath);
            
            // -------
            $xmlDataSet = $this->eSocialService->setXmlFileToDataSet($xml);
            $dataSet = new DataSet($request->getRoutePath(), $xmlDataSet);
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($dsDirXml, $e->getCode()));
        }
    }
    
    public function esvaziaMensagensProcessEnvio () {
        $this->mensagensProcessEnvio = array();
    }
    
    public function addMensagemProcessEnvio ($mensagem, $valor) {
        $mensagensExistentesArray = array_keys($this->mensagensProcessEnvio);
        
        if(!in_array($mensagem, $mensagensExistentesArray)){
            $this->mensagensProcessEnvio[$mensagem] = array($valor);
        } else {
            if(!in_array($valor, $this->mensagensProcessEnvio[$mensagem])){
                array_push($this->mensagensProcessEnvio[$mensagem], $valor);
            }
        }
    }
    
    public function existemMensagensProcessEnvio ($mensagem = null) {
        if (!empty($mensagem)) {
            return array_key_exists($mensagem, $this->mensagensProcessEnvio) ? !empty($this->mensagensProcessEnvio[$mensagem]) : false;
        } else {
            return count($this->mensagensProcessEnvio) > 0;
        }
    }
    
    /**
     * Retorna as mensagens salvas no array 'mensagensProcessEnvio' da seguinte maneira: mensagem1. (valor1, valor2. ...). mensagem2. (valor1, valor2. ...)
     */
    public function getMensagensProcessEnvio () {
        if ($this->existemMensagensProcessEnvio()) {
            $mensagemFinal = "";
            foreach ($this->mensagensProcessEnvio as $chave => $mensagens) {
                $mensagemFinal .= $chave;
                if(is_array($mensagens)){
                    $mensagemValores = "(";
                    foreach ($mensagens as $valor) {
                        $mensagemValores .= $valor . ", ";
                    }
                    $mensagemValores = substr($mensagemValores, 0 , -2);
                    $mensagemValores .= ")";
                    $mensagemFinal .= " " . $mensagemValores;
                }
                $mensagemFinal .= ". ";
            }
            return $mensagemFinal;
        } else {
            return false;
        }
    }

    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );


        return $newFilterCriteria;
    }
    
     public function setEnvio2200ManualSimplificadoAdmissao(DTO\Request\Dataset $request, DTO\Response $response){
        try{
            $dados = $request->getDataSet()->getRows()[0];
            $arrayEnvio = array();
            
            
            foreach ($dados['NRVINCULOM'] as $index => $vinculo) { 
                $paramESocial = $this->eSocialService->getParamESocial($dados['NRESTRUTURAM']);
                if ($paramESocial) {
                    $row['NRTPAMBIENTE'] = $paramESocial['NRTPAMBIENTE'];
                }else{
                    $row['NRTPAMBIENTE'] = 1;
                }
                
                $row['NRCHAVE'] = $vinculo;
                $row['NRTABELA'] = '';
                $row['DSVERSAO'] = $dados['DSVERSAO'];
                $row['IDOPERACAO'] = 'I';
                if($dados['NRTIPOVINCULOM'][$index] == 1) {
                    $row['NREVENTO'] = 'S-2200';
                } else {
                    $row['NREVENTO'] = 'S-2300';
                }
                $row['NRVINCULOM'] = $vinculo;

                $ultimoHist = $this->eSocialService->entityManager->getRepository(Repositories::GPE_VINCULOH)->retornaUltimoHistoricoCompetencia($this->hcmParameters->getNrorgTrabalho(), $vinculo, $this->hcmParameters->getDtcompetencia());
            	
                $row['NRESTRUTURAM'] = $dados['NRESTRUTURAM'];
                $row['DTMESCOMPETENC'] = date_format($ultimoHist->getDtmescompetenc(), 'd/m/Y H:i:s');
                $row['IDSTATUS'] = 'C';
                $row['DSOBSERVACAO'] = 'Inserido manualmente.';
                $row['IDATIVO'] = 'S';
                $row['DSDIRXMLENV'] = null;
                $row['DSDIRXMLRETENV'] = null;
                $row['DSDIRXMLRETPRO'] = null;
                $row['DSDIRXMLRETTOT'] = null;
                
                array_push($arrayEnvio, $row);
            }
            $this->esoSimplificadoService->setEnvio2200ManualSimplificadoAdmissao($arrayEnvio, $response);
            
            $response->addMessage(new DTO\Response\Message('Envios inseridos com sucesso.', DTO\Response\Notification::TYPE_SUCCESS));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));	 
        }
    }
}